@@ -194,13 +194,11 @@ class FluxAgent:
         self.log.info("Successfully registered with primary agent")
 
     async def update_local_agent(self, data: dict):
-        url = f"http://flux{self.primary_agent_name}_{self.app_name}:{self.local_fileserver_port}/register"
-        name = f"flux{self.component_name}_{self.app_name}"
+        url = f"http://flux{self.primary_agent_name}_{self.app_name}:{self.local_fileserver_port}/update"
 
         if self.superior_address and self.superior_port:
             # this means were a subordinate and not on a flux node, basically testing
-            url = f"http://{self.superior_address}:{self.superior_port}/register"
-            name = self.bind_address
+            url = f"http://{self.superior_address}:{self.superior_port}/update"
 
         try:
             async with ClientSession(timeout=ClientTimeout(3)) as session:
@@ -491,7 +489,7 @@ class FluxAgent:
         # print(self.cert.issuer)
         # print(self.cert.subject)
         data = {
-            "name": self.bind_address,
+            "name": f"flux{self.component_name}_{self.app_name}",
             "role": "mongo",
             "enrolled": True,
         }
