@@ -195,7 +195,6 @@ class FluxKeeper:
         self.log.debug(f"Contacting Agent {address} to check if files required")
 
         await agent.transport.connect()
-        print("after transport connect")
         if not agent.transport.connected:
             self.log.info("Transport not connected... skipping.")
             return  # transport will log warning
@@ -204,7 +203,6 @@ class FluxKeeper:
 
         # should this just be a task?
         await self.poll_subordinates(address, agent_proxy)
-        print("finsihed polling subs")
 
         files_to_write = {}
         files = await agent_proxy.get_all_files_crc()
@@ -301,7 +299,6 @@ class FluxKeeper:
         self.log.info(f"Agent {address} has the following subordinates: {subordinates}")
 
         for target, payload in subordinates.get("sub_agents").items():
-            print(payload)
             role = payload.get("role")  # not implemented yet
             enrolled = payload.get("enrolled")
             proxy_port = self.comms_port + 1 if enrolled else self.comms_port
